==> amarok_3.0.1.orig.tar.xz: amarok-3.0.1/src/context/applets/albums/plugin/AlbumsPlugin.cpp <==
/*
 * Copyright 2017  Malte Veerman <malte.veerman@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "AlbumsEngine.h"

#include <QQmlExtensionPlugin>

#include <qqml.h>


class AlbumsPlugin : public QQmlExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid)

public:
    void registerTypes(const char* uri) override
    {
        Q_ASSERT(uri == QLatin1String("org.kde.amarok.albums"));

//         qmlRegisterUncreatableType<AlbumsProxyModel>();
        qmlRegisterSingletonType<AlbumsEngine>(uri, 1, 0, "AlbumsEngine", albums_engine_provider);
    }

    static QObject *albums_engine_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
    {
        Q_UNUSED(engine)
        Q_UNUSED(scriptEngine)

        return new AlbumsEngine();
    }
};

#include <AlbumsPlugin.moc>

==> amarok_3.2.2.orig.tar.xz: amarok-3.2.2/src/context/applets/albums/plugin/AlbumsPlugin.cpp <==
/*
 * Copyright 2017  Malte Veerman <malte.veerman@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "AlbumsEngine.h"

#include <QQmlExtensionPlugin>

#include <qqml.h>


class AlbumsPlugin : public QQmlExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid)

public:
    void registerTypes(const char* uri) override
    {
        Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.amarok.albums"));

//         qmlRegisterUncreatableType<AlbumsProxyModel>();
        qmlRegisterSingletonType<AlbumsEngine>(uri, 1, 0, "AlbumsEngine", albums_engine_provider);
    }

    static QObject *albums_engine_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
    {
        Q_UNUSED(engine)
        Q_UNUSED(scriptEngine)

        return new AlbumsEngine();
    }
};

#include <AlbumsPlugin.moc>
